SQLObject Community — SQLObject 3.9.1 documentation

# SQLObject Community

SQLObject questions and discussion happens on the sqlobject-discuss mailing list.

Bugs should be submitted to the GitHub issue tracker or bug tracker at SourceForge, and patches as pull requests at GitHub or to the patch tracker at SF.

Development takes place in the git repositories. There are development docs, i.e the docs from the development branch (master). If you are interested in contributing you should read the Developer Guide.

The Author List tries to list all the major contributors.

Questions can also be asked and answered on StackOverflow.

One can also contribute to community-editable recipe/documentation site.